@@ -774,10 +774,10 @@ class TestAccessors:
         )
 
     def test_drawdowns(self):
-        assert type(df['a'].vbt.drawdowns()) is Drawdowns
-        assert df['a'].vbt.drawdowns().wrapper.freq == df['a'].vbt.wrapper.freq
-        assert df['a'].vbt.drawdowns().wrapper.ndim == df['a'].ndim
-        assert df.vbt.drawdowns().wrapper.ndim == df.ndim
+        assert type(df['a'].vbt.drawdowns) is Drawdowns
+        assert df['a'].vbt.drawdowns.wrapper.freq == df['a'].vbt.wrapper.freq
+        assert df['a'].vbt.drawdowns.wrapper.ndim == df['a'].ndim
+        assert df.vbt.drawdowns.wrapper.ndim == df.ndim
 
     def test_to_mapped_array(self):
         np.testing.assert_array_equal(
